@@ -6,6 +6,7 @@
  written in VIM editor, ctags used, CVS used
  Currently only one author: MOrgoth DBMA
  FILE: gtkdialogs.c */
+#include "common.h"
 #include "gtkdialogs.h"
 static int answer = ANSWER_YES;
 static char tentry[MAX_ENTRY_LENGTH];
@@ -14,11 +15,27 @@ static char*** ptr = NULL;
 static int row = 0;
 static int col = 0;
 
+int strhasdot(char* str)
+{
+ int l,i;
+ debug("%s:%d",__FILE__,__LINE__);
+ if (!str) return 0;
+ l = strlen(str)-1;
+ for (i=l;i>=0;i--)
+ {
+  if (str[i]=='/') break;
+  if (str[i]=='\\') break;
+  if (str[i]=='.') return 1;
+ }
+ return 0;
+}
+
 int mask_match()
 {
  char tmps[MAX_ENTRY_LENGTH];
  char tmpm[MASK_LENGTH];
  int i,j;
+ debug("%s:%d",__FILE__,__LINE__);
  strcpy(tmps, tentry);
  strcpy(tmpm, fmask);
  downcase(tmps);
@@ -27,15 +44,15 @@ int mask_match()
  j = strlen(tmpm)-1;
  if (j>i) 
    {
-    if (!strstr(tentry,".")) { strcat(tentry, fmask); return 1; }
-    else return 0;
+    if (!strhasdot(tentry)) { strcat(tentry, fmask); return 1; }
+    else return 0; 
    }
  while (j>=0)
    {
     if (tmps[i]!=tmpm[j]) 
       {
-       if (!strstr(tentry,".")) { strcat(tentry, fmask); return 1; }
-       else return 0;
+       if (!strhasdot(tentry)) { strcat(tentry, fmask); return 1; }
+       else return 0; 
       }
     j--;
     i--;
@@ -177,20 +194,31 @@ char* gtk_dialog_gettext_printf(const char* fmt, ...)
  return gtk_dialog_gettext(msg);
 }
 
+char* gtk_dialog_gettext_big_printf(const char* fmt, ...)
+{
+ va_list ap;
+ char msg[MAX_MSG_LENGTH];
+ debug("%s:%d",__FILE__,__LINE__);
+ if (!fmt) return NULL;
+ va_start(ap, fmt);
+ vsprintf(msg,fmt,ap);
+ va_end(ap);
+ return gtk_dialog_gettext_big(msg);
+}
+
 
 char* gtk_dialog_getfile(const char* mask, const char* question)
 {
- GtkWidget* filew;
+ GtkWidget* filew, *flist;
  debug("%s:%d",__FILE__,__LINE__);
  strcpy(fmask,"");
  if (!question)  filew = gtk_file_selection_new("NULL");
  if (strlen(mask)>=MASK_LENGTH) { error("mask too long %s:%d", __FILE__,__LINE__); return NULL; }
  else filew = gtk_file_selection_new(question);
+ gtk_window_set_modal(GTK_WINDOW(filew), 1);
  strcpy(fmask, mask);
- /*gtk_file_selection_set_filename(GTK_FILE_SELECTION(filew), "*.SQL");*/
- /*flist = GTK_FILE_SELECTION(filew)->file_list;
+ flist = GTK_FILE_SELECTION(filew)->file_list;
  gtk_clist_set_auto_sort(GTK_CLIST(flist), TRUE);
- gtk_clist_select_all(GTK_CLIST(flist));*/
  gtk_signal_connect(GTK_OBJECT(filew), "destroy", GTK_SIGNAL_FUNC(destroy_fs), (gpointer)filew);
  gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(filew)->ok_button),
 		 "clicked", GTK_SIGNAL_FUNC(ok_fs), (gpointer)filew);
@@ -201,6 +229,36 @@ char* gtk_dialog_getfile(const char* mask, const char* question)
  return tentry;
 }
 
+char* gtk_dialog_gettext_big(const char* question)
+{
+ GtkWidget* dialog, *label, *button, *entry;
+ debug("%s:%d",__FILE__,__LINE__);
+ if (!question) warn("question=NULL: %s:%d",__FILE__,__LINE__); 
+ strcpy(tentry, "");
+ dialog = gtk_dialog_new();
+ gtk_window_set_title(GTK_WINDOW(dialog), "Enter text");
+ gtk_widget_set_usize(dialog, 600, 100);
+ gtk_window_set_modal(GTK_WINDOW(dialog), 1);
+ label = gtk_label_new(question);
+ entry = gtk_entry_new();
+ gtk_entry_set_max_length(GTK_ENTRY(entry), MAX_ENTRY_LENGTH-2);
+ gtk_signal_connect(GTK_OBJECT(entry), "activate", GTK_SIGNAL_FUNC(entry_proc), (gpointer)dialog);
+ gtk_signal_connect(GTK_OBJECT(entry), "changed", GTK_SIGNAL_FUNC(entry_changed_proc), (gpointer)dialog);
+ gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), label, TRUE, TRUE, 0);
+ gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), entry, TRUE, TRUE, 0);
+ gtk_widget_show(label);
+ gtk_widget_show(entry);
+ gtk_widget_grab_focus(entry);
+ button = gtk_button_new_with_label("OK");
+ gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(ok_proc), (gpointer)dialog);
+ gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area), button, TRUE, TRUE, 0);
+ gtk_signal_connect(GTK_OBJECT(dialog), "delete_event", GTK_SIGNAL_FUNC(delete_event_proc), (gpointer)dialog);
+ gtk_widget_show(button);
+ gtk_widget_show(dialog);
+ gtk_main();
+ return tentry;
+}
+
 
 char* gtk_dialog_gettext(const char* question)
 {
