@@ -21,6 +21,8 @@ int gtk_dialog_with_2_buttons(const char*, char*, char*);
 int gtk_dialog_yes_no_printf(const char*, ...);
 char* gtk_dialog_gettext(const char*);
 char* gtk_dialog_gettext_printf(const char*, ...);
+char* gtk_dialog_gettext_big(const char*);
+char* gtk_dialog_gettext_big_printf(const char*, ...);
 char* gtk_dialog_getfile_printf(const char*, const char*, ...);
 char* gtk_dialog_getfile(const char*, const char*);
 void gtk_dialog_mbox(const char*, const char*);
