@@ -42,6 +42,13 @@ void clear_txt_ctrl(GtkWidget* w);
 void load_proc(GtkWidget* w, gpointer txt);
 void save_proc(GtkWidget* w, gpointer txt);
 void execute_proc(GtkWidget* w, gpointer txt);
+void execute_fast(GtkWidget* w, gpointer opt);
+void execute_fast_one(GtkWidget* w, gpointer opt);
+void execute_fast_two(GtkWidget* w, gpointer opt);
+void execute_fast_thr(GtkWidget* w, gpointer opt);
+void save_results(GtkWidget* w, gpointer resd);
+void save_results_mainwnd(GtkWidget* w, gpointer d);
+void destroy_all_components();
 void update_entry(GtkWidget* w, gpointer d);
 void apply_proc(GtkWidget* w, gpointer d);
 int connect_proc(GtkWidget* w, gpointer d);
@@ -51,7 +58,14 @@ void env_dialog(GtkWidget* www, gpointer d);
 void check_exec_proc(GtkWidget* txt, gpointer dlg);
 void query_executor(GtkWidget* w, gpointer data);
 void get_main_menu( GtkWidget  *window,GtkWidget **menubar );
-void todo();
 int parse_cmdline(int lb, char** par, GtkWidget* w);
+void setup_components();
+void construct_components();
+
+struct result_cache
+{
+ char*** data;
+ int rows,cols;
+};
 
 #endif
