@@ -9,9 +9,7 @@
 #ifndef __MORGOTHDBMA_SIGNALS_H__
 #define __MORGOTHDBMA_SIGNALS_H__
 #include <unistd.h>
-#include <sys/types.h>
 #include <signal.h>
-#include <sys/wait.h>
 #include "gtkdialogs.h"
 void alarm_clock(int);
 void alarm_stop();
