@@ -12,6 +12,7 @@
  ! I CANNOT ADD THEM TO AUTORS, BUT THANKS FOR SUPPORT ME !
  FILE: toolbar.h */
 
+#include "common.h"
 #include "toolbar.h"
 static const char * xpm_new[] = 
 {
@@ -201,6 +202,72 @@ static const char * xpm_env[] =
 "  cc     cc     ",
 "                ",
 };
+static const char * xpm_fexec1[] = 
+{
+"16 16 2 1",
+"       c None",
+"c      c #AAAA00000000",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"                ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+};
+static const char * xpm_fexec2[] = 
+{
+"16 16 2 1",
+"       c None",
+"c      c #0000AAAA0000",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"                ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+};
+static const char * xpm_fexec3[] = 
+{
+"16 16 2 1",
+"       c None",
+"c      c #00000000AAAA",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+"                ",
+"       ccc      ",
+"       ccc      ",
+"       ccc      ",
+};
 
 static const char * xpm_about[] = 
 {
@@ -664,6 +731,19 @@ void get_toolbar(GtkWidget* w, GtkWidget **tb)
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "DB Environment", "Private",pix,env_dialog,NULL);
  gtk_toolbar_append_space(GTK_TOOLBAR(*tb));
+ pix_new = gdk_pixmap_colormap_create_from_xpm_d
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_fexec1);
+ pix = gtk_pixmap_new(pix_new, mask);
+ gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Fast Execute OpenDlg", "Private",pix,execute_fast,(gpointer)(1));
+ pix_new = gdk_pixmap_colormap_create_from_xpm_d
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_fexec2);
+ pix = gtk_pixmap_new(pix_new, mask);
+ gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Fast Execute Filename", "Private",pix,execute_fast,(gpointer)(2));
+ pix_new = gdk_pixmap_colormap_create_from_xpm_d
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_fexec3);
+ pix = gtk_pixmap_new(pix_new, mask);
+ gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Fast Execute Command", "Private",pix,execute_fast,(gpointer)(3));
+ gtk_toolbar_append_space(GTK_TOOLBAR(*tb));
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
 	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_about);
  pix = gtk_pixmap_new(pix_new, mask);
